  function [y, uy] = ComputeWeightedMean(x, ux)
% -------------------------------------------------------------------------
% ComputeWeightedMean.m
%
% Compute the weighted mean and its associated standard uncertainty.
% -------------------------------------------------------------------------
% Input
%	x                      Measured values
%                        Dimension: N x 1
%	ux                     Standard uncertainties associated with measured 
%                        values
%                        Dimension: N x 1
%
% Output
% y                      Weighted mean
%	uy	                   Standard uncertainty associated with weighted mean
% -------------------------------------------------------------------------

  w  = (1./ux).^2;
  y  = sum(w.*x)/sum(w);
  uy = sqrt(1/sum(w));
%
% -------------------------------------------------------------------------
% End ComputeWeightedMean.m
% -------------------------------------------------------------------------
% Data Fusion Software (Release 1)
%
% Authors: T J Esward, P M Harris, C E Matthews, H D Minh and I M Smith
% National Physical Laboratory, UK
% 
% Date: December 2011
% 
% (c) Queen's Printer and Controller of HMSO, 2011
%--------------------------------------------------------------------------