function sq = GenerateQuantizedSignal(s, n, V)
% -------------------------------------------------------------------------
% GenerateQuantizedSignal.m
%
% Generate a quantized version of a signal. 
% -------------------------------------------------------------------------
% Input 
% s                      Signal 
%                        Dimension: m x n 
% 
% n                      Number of bits for quantization 
% 
% V                      Peak value for saturation 
% 
% Output 
% sq                     Quantized signal 
%                        Dimension: m x n 
% -------------------------------------------------------------------------

  q = 2^n-1; 
  T = (2^n)/(2*V); 
  s1 = T*(s + V); 
  s1(s1 < 0) = 0; 
  s1(s1 > q) = q; 
  s2 = floor(s1); 
  s3 = s2 - q/2; 
  sq = V*(s3/(q/2)); 
% 
% -------------------------------------------------------------------------
% End GenerateQuantizedSignal.m
% -------------------------------------------------------------------------
% Data Fusion Software (Release 1)
%
% Authors: T J Esward, P M Harris, C E Matthews, H D Minh and I M Smith
% National Physical Laboratory, UK
% 
% Date: December 2011
% 
% (c) Queen's Printer and Controller of HMSO, 2011
%--------------------------------------------------------------------------