function MeasIn = TimeSeries(workbookpath, measurandworksheet)
% -------------------------------------------------------------------------
% TimeSeries.m
%
% Read information describing a measurand comprising time and measurand
% values from Excel worksheet and store in structure. 
% -------------------------------------------------------------------------
% Input
% workbookpath           Path to Excel workbook
% measurandworksheet     Worksheet containing measurand data 
%
% Output
% MeasIn                 Structure defining true measurand:
%                        t         Time values
%                                  Dimension: m1 x 1
%                        y         Measurand values 
%                                  Dimension: m1 x 1
%                        name      Measurand name
%                                  Dimension: 1 x 1 cell
%                        yStr      Label for plot axis
%                                  Dimension: string
% -------------------------------------------------------------------------

% Display measurand simulation method and name of worksheet. 
%
  fprintf('\nType of measurand simulation: Time series \n');
  fprintf(['Worksheet: %', num2str(length(measurandworksheet)), 's \n'], ...
      measurandworksheet); 
%  
% Read measurand information from worksheet. 
% 
  [num, qName] = xlsread(workbookpath, measurandworksheet, 'B4'); %#ok<ASGLU>
  [num, qUnit] = xlsread(workbookpath, measurandworksheet, 'B5'); %#ok<ASGLU>
  if isempty(qUnit)
      qUnit = {'unit'};
  end
  if isempty(qName)
      qName = {'Measurand'};
      yStr = ['Quantity/', qUnit{1}]; % string for plot axis
  else
      yStr = [qName{1}, '/', qUnit{1}];
  end
%  
  ty = xlsread(workbookpath, measurandworksheet);
%
% Store measurand data in structure.
%
  MeasIn.t    = ty(:, 1);
  MeasIn.y    = ty(:, 2);
  MeasIn.name = qName;
  MeasIn.yStr = yStr;
%  
% -------------------------------------------------------------------------
% End TimeSeries.m
% -------------------------------------------------------------------------
% Data Fusion Software (Release 1)
%
% Authors: T J Esward, P M Harris, C E Matthews, H D Minh and I M Smith
% National Physical Laboratory, UK
% 
% Date: December 2011
% 
% (c) Queen's Printer and Controller of HMSO, 2011
%--------------------------------------------------------------------------